---
title: <span class="badge object-type-scalar"></span> MessagesPerMinute
---
# <span class="badge object-type-scalar"></span> MessagesPerMinute

Throughput: messages/min (mpm)

## Definition

```python
# Throughput: messages/min (mpm)
MessagesPerMinute: typing.Literal["mpm"] = "mpm"
```
